@@ -71,7 +71,7 @@ class OpenEphysRecording(Recording):
 
             self.metadata = {}
 
-            self.metadata['source_node_id'] = info['source_node_id']
+            self.metadata['source_node_id'] = int(info['source_node_id'])
             self.metadata['source_node_name'] = info['source_node_name']
 
             self.metadata['stream_name'] = info['stream_name']
@@ -208,12 +208,13 @@ class OpenEphysRecording(Recording):
 
         def _load_timestamps(self):
 
-            data = np.array(np.memmap(self.timestamps_file, dtype='<f8', offset=0, mode='r'))[self.valid_records]
+            data = np.memmap(self.timestamps_file, dtype='<f8', offset=0, mode='r')[self.valid_records]
             data = np.append(data, 2 * data[-1] - data[-2])
 
-            self._timestamps_internal = np.array([])
+            self._timestamps_internal = []
+
             for i in range(len(data)-1):
-                self._timestamps_internal = np.append(self._timestamps_internal, np.linspace(data[i], data[i+1], 1024, endpoint=True))
+                self._timestamps_internal.extend(np.linspace(data[i], data[i+1], 1024, endpoint=True))
             
             self.timestamps = self._timestamps_internal
 
@@ -275,6 +276,7 @@ class OpenEphysRecording(Recording):
                 for stream_index, stream in enumerate(child):
                     for file_index, file in enumerate(stream):
                         if file.tag == 'EVENTS':
+                            stream_name = file.get('filename').replace('_','.').split('.')[1]
                             sample_number, processor_id, state, channel, header = \
                                 load(os.path.join(self.directory, 
                                       file.get('filename')), self.recording_index)
@@ -282,9 +284,10 @@ class OpenEphysRecording(Recording):
                               'sample_number' : sample_number,
                               'processor_id' : processor_id,
                               'stream_index' : [stream_index] * len(sample_number),
+                              'stream_name' : [stream_name] * len(sample_number),
                               'state' : state}))
 
-        self._events = pd.concat(events).sort_values(by='sample_number')
+        self._events = pd.concat(events).sort_values(by=['sample_number', 'stream_index'], ignore_index=True)
 
     def load_messages(self):
         
